# Reading data

EXtra-data is a separate library for accessing the data stored in the European
XFEL's HDF5 files. You can access it through the `extra.data` module, e.g.:
```python
from extra.data import open_run
```

See the [EXtra-data documentation](https://extra-data.readthedocs.io) for
information about how to use it.
